-- Copyright 2023 Lennart Augustsson
-- See LICENSE file for full license.
module PrimTable() where
import qualified Prelude()              -- do not import Prelude
